{ stdenv, fetchFromGitLab, autoconf, automake, pkg-config, libtool, openblas, hwloc } :
stdenv.mkDerivation rec {
    name = "starpu";
    version = "1.4.7";
    src = fetchFromGitLab {
        repo = "${name}";
        domain = "gitlab.inria.fr";
        owner = "${name}";
        rev = "${name}-${version}";
        hash = "sha256-bYKfVB4oUFQPuwiJ/qFHXfLcKYHm2wCE53itIqCe7pM=";
    };

    nativeBuildInputs = [ 
      autoconf 
      automake
      pkg-config
      libtool
    ];

    buildInputs = [
      openblas
      hwloc
    ];

    postPatch = ''
      substituteInPlace doc/*.sh \
        --replace "#!/bin/bash" ""
    '';

    configurePhase = ''
      ./autogen.sh
      ./configure \
        --prefix=$out \
        --disable-build-doc \
        --disable-build-doc-pdf \
        --disable-build-examples \
        --enable-build-tests \
        --disable-cuda \
        --disable-fortran \
        --disable-mpi \
        --disable-opencl \
        --disable-socl \
        --disable-starpufft \
        --disable-starpupy \
        --enable-blas-lib=openblas \
        --enable-cpu \
        --enable-maxbuffers=16 \
        --enable-maxcpus=16 \
        --enable-openmp \
        --with-pic \
        --with-hwloc
    '';
}
